/// actor_move_x_slope(delta, ?upsteps = 1, ?downsteps = 1, ?upcost = 0, ?downcost = 0)
// Similar to the regular actor_move_x, but with slope support.
// This version is slightly more resource-costly due to multiple checks.
// upsteps determines how steep of a slope the instance can ascent
// downsteps determines how steep of a slope the instance can descent
// @author YellowAfterlife
var delta = argument[0];
var upsteps, downsteps, upcost, downcost;
if (argument_count > 1) upsteps = argument[1]; else upsteps = 1;
if (argument_count > 2) downsteps = argument[2]; else downsteps = 1;
if (argument_count > 3) upcost = argument[3]; else upcost = 0;
if (argument_count > 4) downcost = argument[4]; else downcost = 0;
// handle fractions:
xfrac += abs(delta);
var steps = floor(xfrac);
xfrac -= steps;
// early exit:
if (steps == 0) return true;
// determine the region to check:
var rx1 = bbox_left;
var rx2 = bbox_right;
var ry1 = bbox_top;
var ry2 = bbox_bottom;
// determine the range for checks:
var dy_top = -upsteps;
var dy_bot = downsteps;
if (!actor_is_on_ground()) dy_bot = 0;
// the actual movement loop:
var _sign = sign(delta), taken;
while (steps > 0) {
    rx1 += _sign;
    rx2 += _sign;
    for (var dy = dy_bot; dy >= dy_top; dy--) {
        var ny1 = ry1 + dy;
        var ny2 = ry2 + dy;
        // calculate the cost and ensure that there are enough steps left:
        var nc = 1;
        if (dy > 0) nc += downcost * dy;
        if (dy < 0) nc -= upcost * dy;
        if (steps < nc) continue;
        // ensure that the new position is not blocked:
        if (collision_rectangle(rx1, ny1, rx2, ny2, obj_solid, true, true)) continue;
        // ensure that it has ground undernearth (or it's non-slope movement):
        var npy = ny2 + 1;
        if (dy == 0
        || collision_rectangle(rx1, npy, rx2, npy, obj_solid, true, true)
        || collision_rectangle(rx1, npy, rx2, npy, obj_platform, true, true)) {
            // move the regions and the instance:
            ry1 = ny1;
            ry2 = ny2;
            x += _sign;
            y += dy;
            steps -= nc;
            break;
        }
    }
    if (dy < dy_top) break;
}
// return if the instance had moved as far as intended:
return steps < 1;
