/// crusher_move_x(delta)
// Moves the elevator by the given offset on X axis.
// Any "actors" standing on the way will be pushed or crushed.
// Returns whether the destination was reached
// (as opposed to hitting something on the way).
// Fractions are carried over between the function calls.
// @author YellowAfterlife
var delta = argument0;
// handle fractions:
xfrac += abs(delta);
var steps = floor(xfrac);
xfrac -= steps;
// early exit:
if (steps == 0) return true;
// determine the region to check:
var rx;
if (delta < 0) {
    rx = bbox_left - 1;
} else {
    rx = bbox_right + 1;
}
var ry1 = bbox_top;
var ry2 = bbox_bottom;
// context:
var this = id;
var ctx = platform_move_x_start(this);
// the actual movement loop:
var _sign = sign(delta), taken;
for (taken = 0; taken < steps; taken++) {
    // stop the loop on obstacles:
    if (collision_rectangle(rx, ry1, rx, ry2, obj_solid, true, true)) break;
    if (collision_rectangle(rx, ry1, rx, ry2, obj_bounce, true, true)) break;
    // push (or crush) actors on the way:
    with (obj_actor) {
        var ax;
        if (delta < 0) {
            ax = bbox_right + 1;
        } else {
            ax = bbox_left - 1;
        }
        if (collision_rectangle(ax, bbox_top, ax, bbox_bottom, this, true, true)) {
            if (!actor_move_x(_sign)) {
                // (crushed into a wall)
                instance_destroy();
            }
        }
    }
    // execute post-step to affect the entities standing on the elevator:
    platform_move_x_step(ctx, taken);
    // shift the region and the elevator:
    rx += _sign;
    x += _sign;
}
platform_move_x_post(ctx, taken, delta);
return taken >= steps;
