/// crusher_move_y(delta)
// Moves the elevator by the given offset on Y axis.
// Any "actors" standing on the way will be pushed (incl. through platforms) or crushed.
// Returns whether the destination was reached
// (as opposed to hitting something on the way).
// Fractions are carried over between the function calls.
// @author YellowAfterlife
var delta = argument0;
// handle fractions:
xfrac += abs(delta);
var steps = floor(xfrac);
xfrac -= steps;
// early exit:
if (steps == 0) return true;
// determine the region to check:
var ry;
if (delta < 0) {
    ry = bbox_top - 1;
} else {
    ry = bbox_bottom + 1;
}
var rx1 = bbox_left;
var rx2 = bbox_right;
// context:
var this = id;
// the actual movement loop:
var _sign = sign(delta), taken;
for (taken = 0; taken < steps; taken++) {
    // exit the loop if an obstacle is on the way:
    if (collision_rectangle(rx1, ry, rx2, ry, obj_solid, true, true)) break;
    if (collision_rectangle(rx1, ry, rx2, ry, obj_bounce, true, true)) break;
    // move the region and the platform:
    ry += _sign;
    y += _sign;
    // move the actors on top\bottom:
    with (obj_actor) {
        var ax1 = bbox_left;
        var ax2 = bbox_right;
        var ay = bbox_top - 1;
        if (delta > 0 && collision_rectangle(ax1, ay, ax2, ay, this, true, true)) {
            // (being pushed downwards by the crusher)
            if (!actor_move_y(1)) {
                if (actor_can_fall_through()) {
                    // (drop through a platform)
                    y += 1;
                } else {
                    // (crushed into the floor)
                    instance_destroy();
                }
            }
        } else {
            ay = bbox_bottom + 1 + _sign;
            if (collision_rectangle(ax1, ay, ax2, ay, this, true, true)) {
                // (if standing on top, only crush against the ceiling)
                if (!actor_move_y(_sign) && delta < 0) instance_destroy();
            }
        }
    }
}
return taken >= steps;
