/// shifter_move_y(delta)
// Moves the elevator by the given offset on Y axis.
// Will pass through the actors and other platform-elevators.
// Returns whether the destination was reached
// (as opposed to hitting something on the way).
// Fractions are carried over between the function calls.
// @author YellowAfterlife
var delta = argument0;
// handle fractions:
xfrac += abs(delta);
var steps = floor(xfrac);
xfrac -= steps;
// early exit:
if (steps == 0) return true;
// determine the region to check:
var ry;
if (delta < 0) {
    ry = bbox_top - 1;
} else {
    ry = bbox_bottom + 1;
}
var rx1 = bbox_left;
var rx2 = bbox_right;
// context:
var this = id;
// the actual movement loop:
var _sign = sign(delta), taken;
for (taken = 0; taken < steps; taken++) {
    // exit the loop if an obstacle is on the way:
    if (collision_rectangle(rx1, ry, rx2, ry, obj_solid, true, true)) break;
    if (collision_rectangle(rx1, ry, rx2, ry, obj_bounce, true, true)) break;
    // move the region and the platform:
    ry += _sign;
    y += _sign;
    // move the actors on top:
    with (obj_actor) {
        var ay = bbox_bottom + 1 + _sign;
        if (collision_rectangle(bbox_left, ay, bbox_right, ay, this, true, true)) {
            actor_move_y(_sign);
        }
    }
}
return taken >= steps;
